@@ -26,6 +26,7 @@
 #include "util.h"
 #include "database.h"
 
+#include <QStandardPaths>
 #include <QDebug>
 
 using namespace Baloo;
@@ -33,6 +34,7 @@ using namespace Baloo;
 FileIndexingQueue::FileIndexingQueue(Database* db, QObject* parent)
     : IndexingQueue(parent)
     , m_db(db)
+    , m_testMode(false)
     , m_indexJob(0)
 {
     m_maxSize = 1200;
@@ -86,6 +88,9 @@ void FileIndexingQueue::processNextIteration()
 
     Q_ASSERT(m_indexJob == 0);
     m_indexJob = new FileIndexingJob(files, this);
+    if (m_testMode) {
+        m_indexJob->setCustomDbPath(m_db->path());
+    }
     connect(m_indexJob, SIGNAL(indexingFailed(uint)), this, SLOT(slotIndexingFailed(uint)));
     connect(m_indexJob, SIGNAL(finished(KJob*)), SLOT(slotFinishedIndexingFile(KJob*)));
 
