@@ -25,12 +25,11 @@
 #include <QUrl>
 #include <KUser>
 #include <QDebug>
+#include <QCoreApplication>
 #include <KSharedConfig>
-#include <KApplication>
+#include <KLocalizedString>
 
 #include <KIO/Job>
-#include <KIO/NetAccess>
-#include <kde_file.h>
 
 using namespace Baloo;
 
@@ -59,7 +58,7 @@ KIO::UDSEntry statSearchFolder(const QUrl& url)
 
 bool isRootUrl(const QUrl& url)
 {
-    const QString path = url.path(QUrl::StripTrailingSlash);
+    const QString path = url.path();
     return (!url.hasQuery() &&
             (path.isEmpty() || path == QLatin1String("/")));
 }
@@ -80,7 +79,6 @@ void SearchProtocol::listDir(const QUrl& url)
 {
     // list the root folder
     if (isRootUrl(url)) {
-        listEntry(KIO::UDSEntry(), true);
         finished();
     }
 
@@ -93,8 +91,8 @@ void SearchProtocol::listDir(const QUrl& url)
 
         if (url.isLocalFile()) {
             // Code from kdelibs/kioslaves/file.cpp
-            KDE_struct_stat statBuf;
-            if (KDE_stat(QFile::encodeName(url.toLocalFile()).data(), &statBuf) == 0) {
+            QT_STATBUF statBuf;
+            if (QT_LSTAT(QFile::encodeName(url.toLocalFile()).data(), &statBuf) == 0) {
                 uds.insert(KIO::UDSEntry::UDS_MODIFICATION_TIME, statBuf.st_mtime);
                 uds.insert(KIO::UDSEntry::UDS_ACCESS_TIME, statBuf.st_atime);
                 uds.insert(KIO::UDSEntry::UDS_SIZE, statBuf.st_size);
@@ -113,10 +111,7 @@ void SearchProtocol::listDir(const QUrl& url)
         } else {
             // not a local file
             KIO::StatJob* job = KIO::stat(url, KIO::HideProgressInfo);
-            // we do not want to wait for the event loop to delete the job
-            QScopedPointer<KIO::StatJob> sp(job);
-            job->setAutoDelete(false);
-            if (KIO::NetAccess::synchronousRun(job, 0)) {
+            if (job->exec()) {
                 uds = job->statResult();
             } else {
                 continue;
@@ -130,10 +125,9 @@ void SearchProtocol::listDir(const QUrl& url)
         if (url.isLocalFile())
             uds.insert(KIO::UDSEntry::UDS_LOCAL_PATH, url.toLocalFile());
 
-        listEntry(uds, false);
+        listEntry(uds);
     }
 
-    listEntry(KIO::UDSEntry(), true);
     finished();
 }
 
@@ -168,26 +162,19 @@ void SearchProtocol::stat(const QUrl& url)
     finished();
 
     /*else {
-        error(KIO::ERR_CANNOT_ENTER_DIRECTORY, url.prettyUrl());
+        error(KIO::ERR_CANNOT_ENTER_DIRECTORY, url.toString());
         return;
     }*/
 }
 
 extern "C"
 {
-    KDE_EXPORT int kdemain(int argc, char** argv)
+    Q_DECL_EXPORT int kdemain(int argc, char** argv)
     {
-        // necessary to use other kio slaves
-        KComponentData comp("kio_baloosearch");
         QCoreApplication app(argc, argv);
-
-        qDebug() << "Starting baloosearch slave " << getpid();
-
+        app.setApplicationName(QStringLiteral("kio_baloosearch"));
         Baloo::SearchProtocol slave(argv[2], argv[3]);
         slave.dispatchLoop();
-
-        qDebug() << "baloosearch slave Done";
-
         return 0;
     }
 }
