@@ -22,13 +22,12 @@
 #include "timelinetools.h"
 
 #include <QUrl>
-#include <KCalendarSystem>
-#include <KGlobal>
-#include <KLocalizedString>
+#include <QDate>
+#include <QRegExp>
 #include <QDebug>
 
-#include <QtCore/QDate>
-#include <QtCore/QRegExp>
+#include <KCalendarSystem>
+#include <KLocalizedString>
 
 namespace
 {
@@ -56,7 +55,7 @@ QDate applyRelativeDateModificators(const QDate& date, const QMap<QString, QStri
     if (modificators.contains(weekKey)) {
         int relWeeks = modificators[weekKey].toInt(&ok);
         if (ok) {
-            const KCalendarSystem* calSystem = KGlobal::locale()->calendar();
+            const KCalendarSystem* calSystem = KLocale::global()->calendar();
             newDate = newDate.addDays(relWeeks * calSystem->daysInWeek(date));
         }
     }
@@ -80,7 +79,9 @@ Baloo::TimelineFolderType Baloo::parseTimelineUrl(const QUrl& url, QDate* date,
     // reset
     *date = QDate();
 
-    const QString path = url.path(QUrl::StripTrailingSlash);
+    QString path = url.path();
+    if (path.endsWith(QLatin1Char('/')))
+        path = path.mid(0, path.length()-1);
 
     if (path.isEmpty() || path == QLatin1String("/")) {
         qDebug() << url << "is root folder";
@@ -117,7 +118,14 @@ Baloo::TimelineFolderType Baloo::parseTimelineUrl(const QUrl& url, QDate* date,
                 return MonthFolder;
         } else {
             qDebug() << "parsing " << dateString;
-            *date = applyRelativeDateModificators(QDate::fromString(dateString, "yyyy-MM-dd"), url.queryItems());
+            typedef QPair<QString, QString> StringPair;
+            QList<StringPair> queryItems = url.queryItems();
+            QMap<QString, QString> map;
+            Q_FOREACH (const StringPair& pair, queryItems) {
+                map.insert(pair.first, pair.second);
+            }
+
+            *date = applyRelativeDateModificators(QDate::fromString(dateString, QLatin1String("yyyy-MM-dd")), map);
             // only in day folders we can have filenames
             qDebug() << url << "is day folder:" << *date;
             if (date->isValid())
