@@ -27,7 +27,7 @@
 #include "query.h"
 
 #include <QStringList>
-#include <Akonadi/Collection>
+#include <Collection>
 
 namespace Baloo {
 namespace PIM {
@@ -43,8 +43,6 @@ public:
         OpOr
     };
 
-    void setSplitSearchMatchString(bool split);
-
     void setSearchType(OpType op);
 
     void setInvolves(const QStringList& involves);
